@@ -11,6 +11,7 @@ from toolz import compose
 from aenum import constant
 
 import kfactory as kf
+from kfactory.layout import Constants
 from kfactory import LayerEnum, show, Instance
 from kfactory.layout import kcl
 from kfactory import logger
@@ -69,6 +70,7 @@ from gdsfactory.pdk import (
     get_layer,
     get_layer_tuple,
     get_layer_name,
+    get_layer_info,
     get_active_pdk,
     get_cell,
     get_constant,
@@ -103,6 +105,7 @@ __all__ = (
     "ComponentAlongPath",
     "ComponentBase",
     "ComponentReference",
+    "Constants",
     "CrossSection",
     "Instance",
     "LayerEnum",
@@ -140,6 +143,7 @@ __all__ = (
     "get_cross_section",
     "get_cross_sections",
     "get_layer",
+    "get_layer_info",
     "get_layer_name",
     "get_layer_tuple",
     "get_padding_points",
