@@ -140,15 +140,3 @@ def add_padding_to_size(
 
 add_padding_container = partial(container, function=add_padding)
 add_padding_to_size_container = partial(container, function=add_padding_to_size)
-
-
-if __name__ == "__main__":
-    # test_container()
-
-    # p = partial(add_padding, layers=((1, 0)))
-    c = gf.components.straight(length=10)
-    c1 = add_padding_to_size_container(c, xsize=100, ysize=100)
-    c2 = add_padding_to_size_container(c, xsize=100, ysize=100)
-    print(c1.name)
-    print(c2.name)
-    c2.show()
