@@ -203,37 +203,3 @@ def component_sequence(
         )
 
     return component
-
-
-if __name__ == "__main__":
-    import gdsfactory as gf
-
-    bend180 = gf.components.bend_circular180()
-    wg_pin = gf.components.straight_pin(length=40)
-    wg = gf.components.straight()
-
-    # Define a map between symbols and (component, input port, output port)
-    symbol_to_component_map = {
-        "A": (bend180, "o1", "o2"),
-        "B": (bend180, "o2", "o1"),
-        "H": (wg_pin, "o1", "o2"),
-        "-": (wg, "o1", "o2"),
-    }
-
-    # Each character in the sequence represents a component
-    sequence = "AB"
-    sequence = "HH!"
-    sequence = "!HH"
-    sequence = "H"
-    sequence = "AB-H-H-H-H-BA"
-    c = component_sequence(
-        sequence=sequence, symbol_to_component=symbol_to_component_map
-    )
-    c.show()
-    # n = c.get_netlist()
-    # c = gf.read.from_yaml(n)
-
-    # _ = c << gf.c.straight()
-    # c.name = "top"
-    # lyrdb = c.connectivity_check()
-    # gf.show(c, lyrdb=lyrdb)
