@@ -2,7 +2,7 @@ from __future__ import annotations
 
 import gdsfactory as gf
 from gdsfactory.component import Component
-from gdsfactory.components.shapes import circle
+from gdsfactory.components.shapes.circle import circle
 from gdsfactory.typings import LayerSpec
 
 
@@ -31,8 +31,3 @@ def fiber(
         name="F0", width=core_diameter, orientation=0, center=(0, 0), layer=layer_core
     )
     return c
-
-
-if __name__ == "__main__":
-    c = fiber()
-    c.show()
