@@ -48,8 +48,3 @@ def litho_steps(
         r.movex(count - i)
 
     return D
-
-
-if __name__ == "__main__":
-    c = litho_steps()
-    c.show()
