@@ -452,7 +452,7 @@ def difftest(
     dirpath_ref.mkdir(exist_ok=True, parents=True)
     dirpath_run.mkdir(exist_ok=True, parents=True)
 
-    filename = get_name_short(clean_name(test_name), max_cellname_length=32)
+    filename = get_name_short(clean_name(test_name))
 
     ref_file = dirpath_ref / f"{filename}.gds"
     run_file = dirpath_run / f"{filename}.gds"
@@ -512,38 +512,3 @@ def read_top_cell(arg0: pathlib.Path) -> kf.DKCell:
         for cross_section in kcl.cross_sections.cross_sections.values():
             kf.kcl.get_symmetrical_cross_section(cross_section)
     return kcell
-
-
-if __name__ == "__main__":
-    from gdsfactory.components.waveguides.straight import straight
-
-    # print([i.name for i in c.get_dependencies()])
-    # c.show()
-    # c.name = "mzi"
-    c = straight(length=10)
-    difftest(c, test_name="straight", dirpath=PATH.cwd)
-    c.show()
-    # c.write_gds()
-
-    # component = gf.components.mzi()
-    # test_name = "mzi"
-    # filename = f"{test_name}.gds"
-    # dirpath = PATH.cwd
-    # dirpath_ref = dirpath / "gds_ref"
-    # dirpath_run = GDSDIR_TEMP
-
-    # ref_file = dirpath_ref / f"{test_name}.gds"
-    # run_file = dirpath_run / filename
-    # run = gf.get_component(component)
-    # run_file = run.write_gds(gdspath=run_file)
-
-    # if not ref_file.exists():
-    #     component.write_gds(gdspath=ref_file)
-    #     raise AssertionError(
-    #         f"Reference GDS file for {test_name!r} not found. Writing to {ref_file!r}"
-    #     )
-
-    # ref = read_top_cell(ref_file)
-    # run = read_top_cell(run_file)
-    # ld = kdb.LayoutDiff()
-    # print(ld.compare(ref.kdb_cell, run.kdb_cell))
