@@ -69,7 +69,3 @@ class LAYER(gf.LayerEnum):
 
 
 gf.kcl.layers = LAYER
-
-
-if __name__ == "__main__":
-    LAYER.my_layer = (1, 2)
