@@ -12,7 +12,7 @@ if TYPE_CHECKING:
     from gdsfactory.typings import ComponentOrPath, PathType
 
 
-def from_gdspaths(cells: "Sequence[ComponentOrPath]") -> Component:
+def from_gdspaths(cells: Sequence[ComponentOrPath]) -> Component:
     """Combine all GDS files or gf.components into a gf.component.
 
     Args:
@@ -32,17 +32,8 @@ def from_gdspaths(cells: "Sequence[ComponentOrPath]") -> Component:
     return component
 
 
-def from_gdsdir(dirpath: "PathType") -> Component:
+def from_gdsdir(dirpath: PathType) -> Component:
     """Merges GDS cells from a directory into a single Component."""
     dirpath = pathlib.Path(dirpath)
     assert dirpath.exists(), f"{dirpath} does not exist"
     return from_gdspaths(list(dirpath.glob("*.gds")))
-
-
-if __name__ == "__main__":
-    from gdsfactory.config import diff_path
-
-    # c = gdspaths([gf.components.straight(), gf.components.bend_circular()])
-    # leave these two lines to end up tests showing the diff
-    c = from_gdspaths(list(diff_path.glob("*.gds")))
-    c.show()
