@@ -4,6 +4,7 @@ from pathlib import Path
 from typing import Any
 
 import kfactory as kf
+import kfactory.utilities
 from kfactory import KCLayout
 
 from gdsfactory.component import Component
@@ -50,6 +51,11 @@ def import_gds(
 
 
 def kcell_to_component(kcell: kf.kcell.ProtoTKCell[Any]) -> Component:
+    kcell.set_meta_data()
+
+    for ci in kcell.called_cells():
+        kcell.kcl[ci].set_meta_data()
+
     c = Component()
     c.name = kcell.name
     c.kdb_cell.copy_tree(kcell.kdb_cell)
@@ -79,15 +85,3 @@ def import_gds_with_conflicts(
         SkipNewCell: The new cell is skipped entirely (including child cells which are not used otherwise)
     """
     return import_gds(gdspath, cellname=cellname, rename_duplicated_cells=True)
-
-
-if __name__ == "__main__":
-    from gdsfactory.components import mzi
-
-    c = mzi()
-    c.pprint_ports()
-    gdspath = c.write_gds()
-
-    c = import_gds(gdspath)
-    c.pprint_ports()
-    c.show()
