@@ -250,33 +250,3 @@ def add_pads_top(
     c.add_ports(ref.ports)
     c.copy_child_info(_c)
     return c
-
-
-if __name__ == "__main__":
-    # c = gf.components.pad()
-    c = gf.components.straight_heater_metal(length=100.0)
-    # c = gf.components.straight(length=100.0)
-    # c.pprint_ports()
-    c = gf.routing.add_pads_top(component=c, port_names=("l_e1",), auto_taper=False)
-    # c = gf.routing.add_pads_bot(component=c, port_names=("l_e4", "r_e4"), fanout_length=80)
-    # c = gf.routing.add_fiber_array(c)
-    c.show()
-    # c.show()
-
-    # cc = add_pads_top(component=c, port_names=("e1",))
-    # cc = add_pads_top(component=c, port_names=("e1", "e2"), fanout_length=50)
-    # c = gf.c.nxn(
-    #     xsize=600,
-    #     ysize=200,
-    #     # north=2,
-    #     # south=3,
-    #     north=0,
-    #     south=0,
-    #     west=2,
-    #     east=2,
-    #     wg_width=10,
-    #     layer="M3",
-    #     port_type="electrical",
-    # )
-    # cc = add_pads_top(component=c)
-    # cc.show()
