@@ -12,9 +12,9 @@ route_bundle calls different function depending on the port orientation.
 
 from __future__ import annotations
 
-from collections.abc import Mapping, Sequence
+from collections.abc import Sequence
 from functools import partial
-from typing import Literal
+from typing import Literal, cast
 from warnings import warn
 
 import kfactory as kf
@@ -32,6 +32,7 @@ from gdsfactory.typings import (
     LayerSpecs,
     LayerTransitions,
     Ports,
+    Step,
 )
 
 OpticalManhattanRoute = ManhattanRoute
@@ -68,7 +69,7 @@ def get_min_spacing(
             sorted(ports1, key=get_port_x)
             sorted(ports2, key=get_port_x)
 
-    for port1, port2 in zip(ports1, ports2):
+    for port1, port2 in zip(ports1, ports2, strict=False):
         if axis in {"X", "x"}:
             x1 = get_port_y(port1)
             x2 = get_port_y(port2)
@@ -112,11 +113,13 @@ def route_bundle(
     auto_taper: bool = True,
     auto_taper_taper: ComponentSpec | None = None,
     waypoints: Coordinates | Sequence[gf.kdb.DPoint] | None = None,
-    steps: Sequence[Mapping[str, int | float]] | None = None,
+    steps: Sequence[Step] | None = None,
     start_angles: float | list[float] | None = None,
     end_angles: float | list[float] | None = None,
     router: Literal["optical", "electrical"] | None = None,
     layer_transitions: LayerTransitions | None = None,
+    layer_marker: LayerSpec | None = None,
+    raise_on_error: bool = False,
 ) -> list[ManhattanRoute]:
     """Places a bundle of routes to connect two groups of ports.
 
@@ -153,6 +156,8 @@ def route_bundle(
         router: Set the type of router to use, either the optical one or the electrical one.
             If None, the router is optical unless the port_type is "electrical".
         layer_transitions: dictionary of layer transitions to use for the routing when auto_taper=True.
+        layer_marker: layers to place markers on the route.
+        raise_on_error: if True, raises an exception on routing error instead of adding error markers.
 
     .. plot::
         :include-source:
@@ -178,34 +183,38 @@ def route_bundle(
         c.plot()
 
     """
-    if layer and cross_section:
-        raise ValueError(
-            f"Cannot have both {layer=} and {cross_section=} provided. Choose one."
-        )
     if cross_section is None:
-        if layer is not None and route_width is not None:
-            cross_section = partial(
-                gf.cross_section.cross_section, layer=layer, width=route_width
-            )
-
-        else:
+        if layer is None or route_width is None:
             raise ValueError(
                 f"Either {cross_section=} or {layer=} and {route_width=} must be provided"
             )
+    elif layer is not None:
+        raise ValueError(
+            f"Cannot have both {layer=} and {cross_section=} provided. Choose one."
+        )
 
     c = component
     ports1_ = list(ports1)
     ports2_ = list(ports2)
     port_type = port_type or ports1_[0].port_type
 
+    if cross_section is None:
+        cross_section = partial(
+            gf.cross_section.cross_section,
+            layer=cast(LayerSpec, layer),
+            width=cast(float, route_width),
+            port_names=("e1", "e2") if port_type == "electrical" else ("o1", "o2"),
+            port_types=(port_type, port_type),
+        )
+
     if len(ports1_) != len(ports2_):
         raise ValueError(
             f"ports1={len(ports1_)} and ports2={len(ports2_)} must be equal"
         )
-    if route_width is None or route_width == 0:
-        xs = gf.get_cross_section(cross_section)
-    else:
+    if route_width:
         xs = gf.get_cross_section(cross_section, width=route_width)
+    else:
+        xs = gf.get_cross_section(cross_section)
     width = route_width or xs.width
 
     radius = radius or xs.radius
@@ -232,7 +241,7 @@ def route_bundle(
         ports1_new = []
         ports2_new = []
 
-        for p1, p2 in zip(ports1_, ports2_):
+        for p1, p2 in zip(ports1_, ports2_, strict=False):
             t1 = c << taper_
             t2 = c << taper_
             t1.connect(taper_o1, p1)
@@ -247,11 +256,23 @@ def route_bundle(
         bbox1 = gf.kdb.DBox()
         bbox2 = gf.kdb.DBox()
 
-        for port in ports1_:
-            bbox1 += port.dcplx_trans.disp.to_p()
+        if start_straight_length:
+            p_ = gf.kdb.DPoint(start_straight_length, 0)
+            for port in ports1_:
+                bbox1 += port.dcplx_trans.disp.to_p()
+                bbox1 += port.dcplx_trans * p_
+        else:
+            for port in ports1_:
+                bbox1 += port.dcplx_trans.disp.to_p()
 
-        for port in ports2_:
-            bbox2 += port.dcplx_trans.disp.to_p()
+        if end_straight_length:
+            p_ = gf.kdb.DPoint(end_straight_length, 0)
+            for port in ports2_:
+                bbox2 += port.dcplx_trans.disp.to_p()
+                bbox1 += port.dcplx_trans * p_
+        else:
+            for port in ports2_:
+                bbox2 += port.dcplx_trans.disp.to_p()
 
         bboxes.append(bbox1)
         bboxes.append(bbox2)
@@ -259,11 +280,22 @@ def route_bundle(
     elif auto_taper:
         bbox1 = gf.kdb.DBox()
         bbox2 = gf.kdb.DBox()
-        for port in ports1_:
-            bbox1 += port.dcplx_trans.disp.to_p()
-
-        for port in ports2_:
-            bbox2 += port.dcplx_trans.disp.to_p()
+        if start_straight_length:
+            p_ = gf.kdb.DPoint(start_straight_length, 0)
+            for port in ports1_:
+                bbox1 += port.dcplx_trans.disp.to_p()
+                bbox1 += port.dcplx_trans * p_
+        else:
+            for port in ports1_:
+                bbox1 += port.dcplx_trans.disp.to_p()
+        if end_straight_length:
+            p_ = gf.kdb.DPoint(end_straight_length, 0)
+            for port in ports2_:
+                bbox2 += port.dcplx_trans.disp.to_p()
+                bbox2 += port.dcplx_trans * p_
+        else:
+            for port in ports2_:
+                bbox2 += port.dcplx_trans.disp.to_p()
 
         ports1_ = add_auto_tapers(
             component, ports1_, cross_section=xs, layer_transitions=layer_transitions
@@ -290,19 +322,29 @@ def route_bundle(
         x, y = ports1_[0].center
         for d in steps:
             if not STEP_DIRECTIVES.issuperset(d):
-                invalid_step_directives = list(set(d.keys()) - STEP_DIRECTIVES)
                 raise ValueError(
-                    f"Invalid step directives: {invalid_step_directives}."
+                    f"Invalid step directives: {list(d.keys() - STEP_DIRECTIVES)}."
                     f"Valid directives are {list(STEP_DIRECTIVES)}"
                 )
             x = d.get("x", x) + d.get("dx", 0)
             y = d.get("y", y) + d.get("dy", 0)
             waypoints += [(x, y)]  # type: ignore[arg-type]
+            if layer_marker:
+                marker = component << gf.components.rectangle(
+                    size=(10, 10), layer=layer_marker, centered=True
+                )
+                marker.center = (x, y)
     if waypoints is not None and not isinstance(waypoints[0], kf.kdb.DPoint):
         waypoints_: list[kf.kdb.DPoint] | None = [
             kf.kdb.DPoint(p[0], p[1])  # type: ignore[index]
             for p in waypoints
         ]
+        if layer_marker and waypoints_ is not None:
+            for p in waypoints_:
+                marker = component << gf.components.rectangle(
+                    size=(10, 10), layer=layer_marker, centered=True
+                )
+                marker.center = (p.x, p.y)
     else:
         waypoints_ = waypoints  # type: ignore[assignment]
 
@@ -315,27 +357,59 @@ def route_bundle(
             )
         else:
             layer_ = None
-        return kf.routing.electrical.route_bundle(
-            component,
-            ports1_,
-            ports2_,
-            separation=separation,
-            starts=start_straight_length,
-            ends=end_straight_length,
-            collision_check_layers=[
-                c.kcl.layout.get_info(layer) for layer in collision_check_layer_enums
-            ]
-            if collision_check_layer_enums is not None
-            else None,
-            on_collision=on_collision,
-            bboxes=bboxes,
-            route_width=width,
-            sort_ports=sort_ports,
-            waypoints=waypoints_,
-            end_angles=end_angles,
-            start_angles=start_angles,
-            place_layer=layer_,
-        )
+        try:
+            route = kf.routing.electrical.route_bundle(
+                component,
+                ports1_,
+                ports2_,
+                separation=separation,
+                starts=start_straight_length,
+                ends=end_straight_length,
+                collision_check_layers=[
+                    c.kcl.layout.get_info(layer)
+                    for layer in collision_check_layer_enums
+                ]
+                if collision_check_layer_enums is not None
+                else None,
+                on_collision=on_collision,
+                bboxes=bboxes,
+                route_width=width,
+                sort_ports=sort_ports,
+                waypoints=waypoints_,
+                end_angles=end_angles,
+                start_angles=start_angles,
+                place_layer=layer_,
+            )
+        except Exception as e:
+            if raise_on_error:
+                raise e
+            gf.logger.error(f"Error in route_bundle: {e}")
+            layer_error_path = gf.get_layer_info(gf.CONF.layer_error_path)
+            route = kf.routing.electrical.route_bundle(
+                component,
+                ports1_,
+                ports2_,
+                separation=separation,
+                starts=start_straight_length,
+                ends=end_straight_length,
+                on_collision=on_collision,
+                bboxes=bboxes,
+                route_width=width,
+                sort_ports=sort_ports,
+                end_angles=end_angles,
+                start_angles=start_angles,
+                place_layer=layer_error_path,
+            )
+
+            if waypoints and waypoints_ is not None:
+                layer_marker = gf.CONF.layer_error_path
+                for p in waypoints_:
+                    marker = component << gf.components.rectangle(
+                        size=(10, 10), layer=layer_marker, centered=True
+                    )
+                    marker.center = (p.x, p.y)
+
+        return route
 
     bend90 = (
         bend
@@ -350,32 +424,63 @@ def route_bundle(
             straight, length=length, cross_section=cross_section, width=width
         )
 
-    return kf.routing.optical.route_bundle(
-        component,
-        ports1_,
-        ports2_,
-        separation=separation,
-        straight_factory=straight_um,
-        bend90_cell=bend90,
-        taper_cell=taper_cell,
-        starts=start_straight_length,
-        ends=end_straight_length,
-        min_straight_taper=min_straight_taper,
-        place_port_type=port_type,
-        collision_check_layers=[
-            c.kcl.layout.get_info(layer) for layer in collision_check_layer_enums
-        ]
-        if collision_check_layer_enums
-        else None,
-        on_collision=on_collision,
-        allow_width_mismatch=allow_width_mismatch,
-        bboxes=list(bboxes or []),
-        route_width=width,
-        sort_ports=sort_ports,
-        waypoints=waypoints_,
-        end_angles=end_angles,
-        start_angles=start_angles,
-    )
+    try:
+        route = kf.routing.optical.route_bundle(
+            component,
+            ports1_,
+            ports2_,
+            separation=separation,
+            straight_factory=straight_um,
+            bend90_cell=bend90,
+            taper_cell=taper_cell,
+            starts=start_straight_length,
+            ends=end_straight_length,
+            min_straight_taper=min_straight_taper,
+            place_port_type=port_type,
+            collision_check_layers=[
+                c.kcl.layout.get_info(layer) for layer in collision_check_layer_enums
+            ]
+            if collision_check_layer_enums
+            else None,
+            on_collision=on_collision,
+            allow_width_mismatch=allow_width_mismatch,
+            bboxes=list(bboxes or []),
+            route_width=width,
+            sort_ports=sort_ports,
+            waypoints=waypoints_,
+            end_angles=end_angles,
+            start_angles=start_angles,
+        )
+    except Exception as e:
+        if raise_on_error:
+            raise e
+        gf.logger.error(f"Error in route_bundle: {e}")
+        layer_error_path = gf.get_layer_info(gf.CONF.layer_error_path)
+        route = kf.routing.electrical.route_bundle(
+            component,
+            ports1_,
+            ports2_,
+            separation=separation,
+            starts=start_straight_length,
+            ends=end_straight_length,
+            on_collision=on_collision,
+            bboxes=bboxes,
+            route_width=width,
+            sort_ports=sort_ports,
+            end_angles=end_angles,
+            start_angles=start_angles,
+            place_layer=layer_error_path,
+        )
+
+        if waypoints and waypoints_ is not None:
+            layer_marker = gf.CONF.layer_error_path
+            for p in waypoints_:
+                marker = component << gf.components.rectangle(
+                    size=(10, 10), layer=layer_marker, centered=True
+                )
+                marker.center = (p.x, p.y)
+
+    return route
 
 
 route_bundle_electrical = partial(
@@ -383,168 +488,3 @@ route_bundle_electrical = partial(
     bend="wire_corner",
     allow_width_mismatch=True,
 )
-
-
-if __name__ == "__main__":
-    import gdsfactory as gf
-    from gdsfactory.generic_tech import LAYER
-
-    pdk = gf.get_active_pdk()
-    pdk.layer_transitions[LAYER.WG] = partial(
-        gf.c.taper, cross_section="rib", length=20
-    )
-    pdk.layer_transitions[LAYER.WG, LAYER.WGN] = gf.c.taper_sc_nc
-    pdk.layer_transitions[LAYER.WGN, LAYER.WG] = gf.c.taper_nc_sc
-
-    # c = gf.Component()
-    # columns = 2
-    # ptop = c << gf.components.pad_array(columns=columns, port_orientation=270)
-    # pbot = c << gf.components.pad_array(port_orientation=270, columns=columns)
-    # # pbot = c << gf.components.pad_array(port_orientation=90, columns=columns)
-
-    # ptop.movex(300)
-    # ptop.movey(300)
-    # routes = gf.routing.route_bundle_electrical(
-    #     c,
-    #     list(reversed(pbot.ports)),
-    #     ptop.ports,
-    #     # end_straight_length=50,
-    #     start_straight_length=100,
-    #     separation=20,
-    #     bboxes=[ptop.bbox(), pbot.bbox()],
-    #     cross_section="metal_routing",
-    #     start_angles=None,
-    #     end_angles=None,
-    #     route_width=2,
-    #     steps=[
-    #         {"dy": 1, "dx": 1},
-    #         {"dy": 2, "dx": 1},
-    #     ],
-    # )
-
-    # c.show()
-    # pbot.ports.print()
-
-    c = gf.Component(name="demo")
-    c1 = c << gf.components.mmi2x2()
-    c2 = c << gf.components.mmi2x2()
-    c2.move((100, 70))
-    routes = route_bundle(
-        c,
-        [c1.ports["o2"], c1.ports["o1"]],
-        [c2.ports["o2"], c2.ports["o1"]],
-        separation=5,
-        cross_section="strip",
-        sort_ports=True,
-        # end_straight_length=0,
-        # collision_check_layers=[(1, 0)],
-        # bboxes=[c1.bbox(), c2.bbox()],
-        # layer=(2, 0),
-        # straight=partial(gf.components.straight, layer=(2, 0), width=1),
-    )
-    c.show()
-
-    # dy = 200.0
-    # xs1 = [-500, -300, -100, -90, -80, -55, -35, 200, 210, 240, 500, 650]
-    # pitch = 10.0
-    # N = len(xs1)
-    # xs2 = [-20 + i * pitch for i in range(N // 2)]
-    # xs2 += [400 + i * pitch for i in range(N // 2)]
-    # a1 = 90
-    # a2 = a1 + 180
-
-    # ports1 = [
-    #     gf.Port(
-    #         f"bot_{i}", center=(xs1[i], +0), width=0.5, orientation=a1, layer=(1, 0)
-    #     )
-    #     for i in range(N)
-    # ]
-    # ports2 = [
-    #     gf.Port(
-    #         f"top_{i}", center=(xs2[i], dy), width=0.5, orientation=a2, layer=(1, 0)
-    #     )
-    #     for i in range(N)
-    # ]
-
-    # c = gf.Component()
-    # route_bundle(
-    #     c,
-    #     ports1,
-    #     ports2,
-    #     end_straight_length=1,
-    #     start_straight_length=100,
-    # )
-    # c.add_ports(ports1)
-    # c.add_ports(ports2)
-    # c.show()
-
-    # nitride case
-    # c = gf.Component()
-    # c1 = c << gf.components.straight(width=0.5, cross_section="strip")
-    # c2 = c << gf.components.straight(cross_section="strip", width=0.5)
-    # c2.move((150, 50))
-    # routes = route_bundle(
-    #     c,
-    #     [c1.ports["o2"]],
-    #     [c2.ports["o1"]],
-    #     separation=5,
-    #     cross_section="nitride",
-    #     auto_taper=True,
-    # )
-    # c.show()
-
-    # rib
-
-    c = gf.Component()
-    c1 = c << gf.components.straight(cross_section="rib", width=2)
-    c2 = c << gf.components.straight(cross_section="rib", width=2)
-    c2.move((300, 90))
-    routes = route_bundle(
-        c,
-        [c1.ports["o2"]],
-        [c2.ports["o1"]],
-        # waypoints=[(200, 40), (200, 50)],
-        # steps=[dict(dx=50, dy=100)],
-        # steps=[dict(dx=50, dy=100), dict(dy=100)],
-        separation=5,
-        cross_section="rib",
-        # auto_taper=True,
-        auto_taper_taper=partial(
-            gf.c.taper, cross_section="rib", length=10, width1=2, width2=1
-        ),
-        route_width=1,
-        # auto_taper=False,
-        # taper=gf.c.taper_sc_nc,
-        # taper=gf.c.taper,
-    )
-    c.show()
-
-    # c = gf.Component()
-    # w = gf.components.array(gf.c.straight, columns=1, rows=3, spacing=(3, 3))
-    # left = c << w
-    # right = c << w
-    # right.move((100, 80))
-
-    # obstacle = gf.components.rectangle(size=(100, 10))
-    # obstacle1 = c << obstacle
-    # obstacle2 = c << obstacle
-    # obstacle1.ymin = 40
-    # obstacle2.xmin = 35
-
-    # ports1 = left.ports.filter(orientation=0)
-    # ports2 = right.ports.filter(orientation=180)
-
-    # routes = gf.routing.route_bundle(
-    #     c,
-    #     ports1,
-    #     ports2,
-    #     steps=[
-    #         {"dy": 30, "dx": 50},
-    #         {"dy": 30, "dx": 50},
-    #         # {"dx": 90},
-    #     ],
-    #     cross_section="strip",
-    #     # layer=(2, 0),
-    #     route_width=0.2,
-    # )
-    # c.show()
