@@ -62,49 +62,3 @@ def route_bundle_all_angle(
         bend_ports=bend_ports,
         straight_ports=straight_ports,
     )
-
-
-if __name__ == "__main__":
-    import gdsfactory as gf
-
-    # c = gf.Component()
-    # rows = 3
-    # w1 = c << gf.c.array("straight", spacing=(0, 10), rows=rows, columns=1)
-    # w2 = c << gf.c.array("straight", spacing=(0, 10), rows=rows, columns=1)
-    # w2.rotate(-30)
-    # w2.movex(140)
-    # p1 = list(w1.ports.filter(orientation=0))
-    # p2 = list(w2.ports.filter(orientation=150))
-    # p1.reverse()
-    # p2.reverse()
-    # c1 = np.array(p2[0].center)
-    # c2 = np.array(p1[0].center)
-    # d = (np.array(p2[0].center) + np.array(p1[0].center)) / 2
-    # backbone = [
-    #     d - (10.0, 0),
-    #     d + (10.0, 0),
-    # ]
-    # route_bundle_all_angle(
-    #     c,
-    #     p1,
-    #     p2,
-    #     backbone=backbone,
-    #     separation=3,
-    # )
-
-    c = gf.Component()
-
-    mmi = gf.components.mmi2x2(width_mmi=10, gap_mmi=3)
-    mmi1 = c.create_vinst(mmi)  # create a virtual instance
-    mmi2 = c.create_vinst(mmi)  # create a virtual instance
-
-    mmi2.move((100, 10))
-    mmi2.rotate(30)
-
-    routes = route_bundle_all_angle(
-        c,
-        mmi1.ports.filter(orientation=0),
-        [mmi2.ports["o2"], mmi2.ports["o1"]],
-    )
-
-    c.show()
