@@ -48,7 +48,7 @@ def route_bundle_sbend(
 
     routes = []
 
-    for p1, p2 in zip(list(ports1), list(ports2)):
+    for p1, p2 in zip(list(ports1), list(ports2), strict=False):
         ys = p2.center[1] - p1.center[1]
         xs = p2.center[0] - p1.center[0]
 
@@ -87,57 +87,3 @@ def route_bundle_sbend(
         )
         routes.append(route)
     return routes
-
-
-if __name__ == "__main__":
-    import gdsfactory as gf
-
-    # c = gf.Component(name="test_route_single_sbend")
-    # pitch = 2.0
-    # ys_left = [0, 10, 20]
-    # N = len(ys_left)
-    # y0 = -10
-    # ys_right = [(i - N / 2) * pitch + y0 for i in range(N)]
-    # layer = (1, 0)
-    # right_ports = [
-    #     gf.Port(
-    #         f"R_{i}", center=(0, ys_right[i]), width=0.5, orientation=180, layer=layer
-    #     )
-    #     for i in range(N)
-    # ]
-    # left_ports = [
-    #     gf.Port(
-    #         f"L_{i}", center=(-50, ys_left[i]), width=0.5, orientation=0, layer=layer
-    #     )
-    #     for i in range(N)
-    # ]
-    # left_ports.reverse()
-    # routes = gf.routing.route_bundle_sbend(
-    #     c, right_ports, left_ports, enforce_port_ordering=False
-    # )
-
-    # c = gf.Component()
-    # c1 = c << gf.components.nxn(east=3, ysize=20)
-    # c2 = c << gf.components.nxn(west=3)
-    # c2.move((80, 0))
-    # route_bundle_sbend(
-    #     c,
-    #     c1.ports.filter(orientation=0),
-    #     c2.ports.filter(orientation=180),
-    #     enforce_port_ordering=False,
-    # )
-
-    c = gf.Component()
-    c1 = c << gf.components.straight_heater_metal()
-    p1 = c << gf.c.pad()
-    p1.movey(200)
-    route_bundle_sbend(
-        c,
-        [p1["e4"]],
-        [c1.ports["l_e2"]],
-        enforce_port_ordering=False,
-        cross_section="metal3",
-        port_name="e1",
-        allow_width_mismatch=True,
-    )
-    c.show()
