@@ -543,42 +543,3 @@ def route_ports_to_y(
         start_straight_length_section += separation
 
     return routes, new_ports
-
-
-if __name__ == "__main__":
-    c = Component()
-    cross_section = "strip"
-    dummy = gf.c.nxn(north=2, south=2, west=2, east=2, cross_section=cross_section)
-    dummy_ref = c << dummy
-    # routes, _ = route_ports_to_side(
-    #     c,
-    #     ports=dummy_ref.ports,
-    #     side="south",
-    #     cross_section=cross_section,
-    #     y=-91,
-    #     x=-100,
-    # )
-    # routes, _ = gf.routing.route_ports_to_side(
-    #     c,
-    #     ports=dummy_ref.ports,
-    #     cross_section=cross_section,
-    #     x=50,
-    #     side="east",
-    # )
-    routes, _ = route_ports_to_side(
-        c,
-        ports=dummy_ref.ports,
-        cross_section=cross_section,
-        y=50,
-        side="north",
-    )
-    # sides = ["north", "south", "east", "west"]
-    # d = 100
-    # positions = [(0, 0), (d, 0), (d, d), (0, d)]
-
-    # for pos, side in zip(positions, sides):
-    #     dummy_ref = c << dummy
-    #     dummy_ref.center = pos
-    #     routes = route_ports_to_side(c, dummy_ref.ports, side, layer=(1, 0))
-
-    c.show()
