@@ -61,13 +61,3 @@ def route_single_sbend(
             f"port1 = {port1.orientation} deg and port2 = {port2.orientation}"
         )
     return bend_ref
-
-
-if __name__ == "__main__":
-    c = gf.Component(name="demo_route_sbend")
-    mmi1 = c << gf.components.mmi1x2()
-    mmi2 = c << gf.components.mmi1x2()
-    mmi2.movex(50)
-    mmi2.movey(5)
-    route_single_sbend(c, mmi1.ports["o2"], mmi2.ports["o1"])
-    c.show()
