@@ -11,7 +11,7 @@ from __future__ import annotations
 import gdsfactory as gf
 
 if __name__ == "__main__":
-    c = gf.Component("lidar")
+    c = gf.Component()
     noutputs = 2**2
     antenna_pitch = 2.0
     splitter_tree_spacing = (50.0, 70.0)
@@ -21,7 +21,8 @@ if __name__ == "__main__":
         gf.components.straight(),
         rows=noutputs,
         columns=1,
-        spacing=(0, 40),
+        column_pitch=0,
+        row_pitch=40,
         centered=True,
     )
 
@@ -30,11 +31,12 @@ if __name__ == "__main__":
         gf.components.dbr(n=200),
         rows=noutputs,
         columns=1,
-        spacing=(0, antenna_pitch),
+        column_pitch=0,
+        row_pitch=antenna_pitch,
         centered=True,
     )
-    antennas.dxmin = ref.dxmax + 100
-    antennas.dy = 0
+    antennas.xmin = ref.xmax + 100
+    antennas.y = 0
 
     routes = gf.routing.route_bundle(
         c,
@@ -42,6 +44,7 @@ if __name__ == "__main__":
         ports2=ref.ports.filter(orientation=0),
         radius=5,
         sort_ports=True,
+        cross_section="strip",
     )
 
     c.show()
