@@ -5,12 +5,12 @@ from __future__ import annotations
 import gdsfactory as gf
 
 if __name__ == "__main__":
-    c = gf.Component("sample_bundle_impossible")
+    c = gf.Component()
 
     top = c << gf.components.nxn(north=8, south=0, east=0, west=0)
     bot = c << gf.components.nxn(north=2, south=2, east=2, west=2, xsize=10, ysize=10)
 
-    top.dmovey(100)
+    top.movey(100)
 
     routes = gf.routing.route_bundle(
         c,
@@ -18,6 +18,7 @@ if __name__ == "__main__":
         ports2=top.ports,
         radius=5,
         sort_ports=True,
+        cross_section="strip",
     )
 
     c.show()
