@@ -27,8 +27,8 @@ def gap_min(gap: float = 0.1) -> Component:
     c = gf.Component()
     r1 = c << gf.components.rectangle(size=(1, 1), layer=layer)
     r2 = c << gf.components.rectangle(size=(1, 1), layer=layer)
-    r1.dxmax = 0
-    r2.dxmin = gap
+    r1.xmax = 0
+    r2.xmin = gap
     return c
 
 
@@ -39,8 +39,8 @@ def separation(
     c = gf.Component()
     r1 = c << gf.components.rectangle(size=(1, 1), layer=layer1)
     r2 = c << gf.components.rectangle(size=(1, 1), layer=layer2)
-    r1.dxmax = 0
-    r2.dxmin = gap
+    r1.xmax = 0
+    r2.xmin = gap
     return c
 
 
@@ -57,7 +57,7 @@ def enclosing(
     c = gf.Component()
     c << gf.components.rectangle(size=(w1, w1), layer=layer1, centered=True)
     r2 = c << gf.components.rectangle(size=(w2, w2), layer=layer2, centered=True)
-    r2.dmovex(0.5)
+    r2.movex(0.5)
     return c
 
 
@@ -66,8 +66,8 @@ def snapping_error(gap: float = 1e-3) -> Component:
     c = gf.Component()
     r1 = c << gf.components.rectangle(size=(1, 1), layer=layer)
     r2 = c << gf.components.rectangle(size=(1, 1), layer=layer)
-    r1.dxmax = 0
-    r2.dxmin = gap
+    r1.xmax = 0
+    r2.xmin = gap
     return c
 
 
