@@ -5,12 +5,12 @@ if __name__ == "__main__":
     columns = 2
     ptop = c << gf.components.pad_array(columns=columns, port_orientation=270)
     pbot = c << gf.components.pad_array(port_orientation=270, columns=columns)
-    ptop.dmovex(300)
-    ptop.dmovey(300)
+    ptop.movex(300)
+    ptop.movey(300)
 
     obstacle = c << gf.c.rectangle(size=(300, 100), layer="M3")
-    obstacle.dymin = pbot.dymax - 10
-    obstacle.dxmin = pbot.dxmax - 10
+    obstacle.ymin = pbot.ymax - 10
+    obstacle.xmin = pbot.xmax - 10
 
     routes = gf.routing.route_bundle_electrical(
         c,
@@ -24,6 +24,7 @@ if __name__ == "__main__":
             ptop.bbox(),
         ],  # obstacles to avoid
         sort_ports=True,
+        cross_section=gf.cross_section.metal_routing,
     )
 
     c.show()
