@@ -11,7 +11,6 @@ from pydantic import BaseModel, ConfigDict, Field, model_validator
 import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.config import PATH
-from gdsfactory.serialization import convert_tuples_to_lists
 from gdsfactory.typings import Anchor, Delta, Port, Ports
 from gdsfactory.utils import is_component_spec
 
@@ -434,12 +433,11 @@ class Schematic(BaseModel):
             netlist: netlist to write.
             filepath: Optional file path to write to.
         """
-        netlist_converted = convert_tuples_to_lists(netlist)
-        yaml_string = yaml.dump(netlist_converted)
+        yaml_string = yaml.safe_dump(netlist)
         if filepath:
             filepath = pathlib.Path(filepath)
             filepath.write_text(yaml_string)
-        return str(yaml_string)
+        return yaml_string
 
 
 def plot_graphviz(
